@@ -42,7 +42,7 @@ spPhoto <- function(
     }
     else{
     require(RCurl)
-    z <- getURI(filename, .opts=curlOptions(header=TRUE, nobody=TRUE, transfertext=TRUE, failonerror=FALSE))
+    z <- RCurl::getURI(filename, .opts=RCurl::curlOptions(header=TRUE, nobody=TRUE, transfertext=TRUE, failonerror=FALSE))
       if(!length(x <- grep(z, pattern="404 Not Found"))==0){
         stop(paste("File", filename, "could not be located."))
       }
